@@ -1,6 +1,6 @@
 '''
 pystata-kernel
-Version: 0.1.19
+Version: 0.1.22
 A simple Jupyter kernel based on pystata.
 Requires Stata 17 and stata_setup.
 '''
@@ -9,10 +9,11 @@ from ipykernel.ipkernel import IPythonKernel
 from .config import get_config
 import os
 import sys
+from packaging import version
 
 class PyStataKernel(IPythonKernel):
     implementation = 'pystata-kernel'
-    implementation_version = '0.1.19'
+    implementation_version = '0.1.22'
     language = 'stata'
     language_version = '17'
     language_info = {
@@ -29,6 +30,7 @@ class PyStataKernel(IPythonKernel):
         self.shell.execution_count = 0
         self.echo = False
         self.suppress = False
+        self.magic_handler = None
 
     def launch_stata(self, path, edition, splash=True):
         """
@@ -41,8 +43,12 @@ class PyStataKernel(IPythonKernel):
             raise OSError(path + " is not Stata's installation path")
 
         sys.path.append(os.path.join(path, 'utilities'))
-        from pystata import config
-        config.init(edition,splash=splash)
+        import pystata
+        if version.parse(pystata.__version__) >= version.parse("0.1.1"):
+            # Splash message control is a new feature of pystata-0.1.1
+            pystata.config.init(edition,splash=splash)
+        else:
+            pystata.config.init(edition)
 
     def do_execute(self, code, silent, store_history=True, user_expressions=None,
                    allow_stdin=False):
@@ -53,15 +59,16 @@ class PyStataKernel(IPythonKernel):
             self.launch_stata(env['stata_dir'],env['edition'],
                     False if env['splash']=='False' else True)
 
-            # pystata must be loaded after stata_setup
-            from pystata.config import set_graph_format 
+            import pystata                    
 
             # Set graph format
             if env['graph_format'] == 'pystata':
                 pass
             else:
+                from pystata.config import set_graph_format
                 set_graph_format(env['graph_format'])
 
+            # Echo options
             if env['echo'] not in ('True','False','None'):
                 raise OSError("'" + env['echo'] + "' is not an acceptable value for 'echo'.")
             else:
@@ -70,14 +77,18 @@ class PyStataKernel(IPythonKernel):
                 elif env['echo'] == 'True':
                     self.echo = True
 
+            # Magics
+            from .magics import StataMagics
+            self.magic_handler = StataMagics()
+
             self.stata_ready = True
-        
-        # Execute Stata code
-        from pystata.stata import run
-        
-        if self.suppress == True:        
-            code = "noisily: " + code.replace("\n","\nnoisily: ") 
-        run(code, quietly=self.suppress, inline=True, echo=self.echo)
+
+        code = self.magic_handler.magic(code,self)              
+        if code != '':
+            # Execute Stata code after magics
+            from pystata.stata import run
+            run(code, quietly=self.suppress, inline=True, echo=self.echo)
+
         self.shell.execution_count += 1
 
         return {'status': 'ok',
